import os
from urllib.parse import urljoin, urlencode
import requests


class VisaTest:

    def get_test_sms_msg(phone_no: str):
        try:
            params = {
                "activationId": phone_no
            }
            sms_base_url = "https://sms.poemhub.top/post/sms/v1/sms-active" #os.environ.get("SMS_TEST_BASE_URL")
            url = urljoin(sms_base_url, "?" + urlencode(params))
            response = requests.get(url=url, timeout=10)
            data = response.json()
            if data["statusCode"] == "200" and data["resultCode"] == "200":
                result = data["result"]
                return result["text"]
            return None
        except Exception as e:
            print(e)

    if __name__ == '__main__':
        get_test_sms_msg(str(15683761628))



import jwt
from rdpywheel.utils.rd_time_utils import RdTimeUtils


class JwtHandler:

    @staticmethod
    def token_is_expire(access_token):
        parsed_token = jwt.decode(access_token,
                                  verify=False,
                                  algorithms=['HS512'],
                                  options={
                                      'verify_signature': False
                                  })
        exp = parsed_token["exp"]
        now = RdTimeUtils.get_current_time_seconds()
        if now - 500 > exp:
            return True
        else:
            return False



# --encoding:utf-8--

import os
import configparser

current_env = os.getenv("ENV")
config = configparser.ConfigParser()
parentDirPath = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
config_file_name = "/config.ini"
if current_env == "PRO":
    config_file_name = "/config-pro.ini"
elif current_env == "TENCENT":
    config_file_name = "/config-tencent.ini"
with open(parentDirPath + config_file_name, "r") as config_file:
    config.readfp(config_file)


class ConfigReader:
    def __init__(self):
        return

    @staticmethod
    def get_value(schema, key):
        return config.get(schema, key)

    @staticmethod
    def get_value(schema, key):
        return config.get(schema, key)

    @staticmethod
    def get_global_value(self, key):
        return config.get('global', key)


import os
from urllib.parse import urljoin, urlencode
import requests
from time import sleep

from rdpywheel.sms import CnVirtMsg
from rdpywheel.sms.visa_test import VisaTest


class SMSUtil:

    def get_platform_vfs_code(self, phone_no: str, token: str):
        is_test = os.environ.get("SMS_TEST_ENABLE")
        if is_test:
            return SMSUtil.query_test_vfs_code(phone_no)
        else:
            return SMSUtil.query_vfs_code(phone_no, token)

    def query_test_vfs_code(phone_no):
        i = 0
        sleep(10)
        code = None
        while True:
            i += 1
            msg = VisaTest.get_test_sms_msg(phone_no=phone_no)
            if msg and len(msg) > 0:
                code = SMSUtil.get_vfs_code(msg)
            sleep(5)
            if code:
                break
            if i > 6:
                return None
        return code

    def query_vfs_code(phone_no, token):
        i = 0
        sleep(10)
        code = None
        while True:
            i += 1
            msg = CnVirtMsg.get_sms_msg(token=token, phone_no=phone_no, key_word="VFS")
            if msg and len(msg) > 0:
                code = SMSUtil.get_vfs_code(msg)
            sleep(5)
            if code:
                break
            if i > 6:
                return None
        return code

    def get_vfs_code(text):
        start_index = text.find('>')
        end_index = text.find(' is')
        if start_index != -1 and end_index != -1:
            otp = text[start_index + 1:end_index]
            print("验证码:", otp)
            return otp

        start_index = text.find('】')
        end_index = text.find(' is')

        if start_index != -1 and end_index != -1:
            otp = text[start_index + 1:end_index]
            print("验证码:", otp)
            return otp
        else:
            print("未找到验证码.")
            return None

    def get_test_sms_msg(activationId: str):
        try:
            params = {
                "activationId": activationId
            }
            sms_base_url = "https://sms.poemhub.top/post/sms/v1/sms-active"  # os.environ.get("SMS_TEST_BASE_URL")
            url = urljoin(sms_base_url, "?" + urlencode(params))
            response = requests.get(url=url, timeout=10)
            data = response.json()
            if data["statusCode"] == "200" and data["resultCode"] == "200":
                result = data["result"]
                return result["text"]
            return None
        except Exception as e:
            print(e)

    if __name__ == '__main__':
        get_test_sms_msg(str(15683761628))



import os


class EnvReader:

    @staticmethod
    def read_bool_env(key: str):
        bool_prev = os.environ.get(key)
        bool_value = None
        if bool_prev is not None:
            bool_value = bool_prev.lower() in ("true", "1", "yes")
        return bool_value




from setuptools import setup, find_packages

setup(
    name='rdpywheel',
    version='0.1.16',
    keywords='wheel',
    description='a library for Python wheel',
    license='MIT License',
    url='https://github.com/jiangxiaoqiang/rdpywheel',
    author='jiangxiaoqiang',
    author_email='jiangtingqiang@gmail.com',
    packages=find_packages(),
    include_package_data=True,
    platforms='any',
    install_requires=[],
)



import os
from urllib.parse import urljoin, urlencode
import requests


class CnVirtMsg:
    def get_sms_phone_number(token: str):
        try:
            params = {
                "code": "getPhone",
                "token": token,
                "cardType": "实卡"
            }
            sms_base_url = os.environ.get("CN_VIRTUAL_BASE_URL")
            url = urljoin(sms_base_url, "?" + urlencode(params))
            response = requests.get(url=url, timeout=10)
            data = response.content
            string_data = data.decode('utf-8')
            return string_data
        except Exception as e:
            print(e)

    def get_sms_msg(token: str, phone_no: str, key_word: str):
        try:
            params = {
                "code": "getMsg",
                "token": token,
                "phone": phone_no,
                "keyWord": key_word
            }
            sms_base_url = os.environ.get("CN_VIRTUAL_BASE_URL")
            url = urljoin(sms_base_url, "?" + urlencode(params))
            response = requests.get(url=url, timeout=10)
            data = response.content
            string_data = data.decode('utf-8')
            return string_data
        except Exception as e:
            print(e)

    def block_phone(token: str, phone_no: str):
        try:
            params = {
                "code": "block",
                "token": token,
                "phone": phone_no,
            }
            sms_base_url = os.environ.get("CN_VIRTUAL_BASE_URL")
            url = urljoin(sms_base_url, "?" + urlencode(params))
            response = requests.get(url=url, timeout=10)
            data = response.content
            string_data = data.decode('utf-8')
            return string_data
        except Exception as e:
            print(e)

